package logic

import (
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"time"

	"context"

	"fusenapi/server/info/internal/svc"
	"fusenapi/server/info/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type AddressUpdateLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewAddressUpdateLogic(ctx context.Context, svcCtx *svc.ServiceContext) *AddressUpdateLogic {
	return &AddressUpdateLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *AddressUpdateLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *AddressUpdateLogic) AddressUpdate(req *types.AddressRequest, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null

	if !userinfo.IsUser() {
		return resp.SetStatus(basic.CodeUnAuth)
	}

	now := time.Now().UTC()

	if req.AddressId == 0 {
		return resp.SetStatusWithMessage(basic.CodeApiErr, "address_id must setting")
	}

	address := gmodel.FsAddress{
		AddressId: req.AddressId,
		UserId:    &userinfo.UserId,
		IsDefault: &req.IsDefault,
		FirstName: &req.FirstName,
		LastName:  &req.LastName,
		Mobile:    &req.Mobile,
		ZipCode:   &req.ZipCode,
		Street:    &req.Street,
		Suite:     &req.Suite,
		City:      &req.City,
		State:     &req.State,
		Utime:     &now,
	}

	err := l.svcCtx.AllModels.FsAddress.UpdateAddress(l.ctx, &address)
	if err != nil {
		return resp.SetStatusWithMessage(basic.CodeApiErr, err.Error())
	}

	return resp.SetStatus(basic.CodeOK)
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *AddressUpdateLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
